# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import requests

from django.conf import settings
from django.db import models
from django import template
from django.utils.translation import ugettext_lazy as _
from django.utils.http import urlencode

from combo.data.models import CellBase
from combo.data.library import register_cell_class
from combo.utils import NothingInCacheException, sign_url


@register_cell_class
class FamilyInfosCell(CellBase):
    template_name = 'family/infos.html'
    user_dependant = True

    class Meta:
        verbose_name = _('Family Information Cell')

    class Media:
        js = ('xstatic/jquery-ui.min.js', 'js/gadjo.js',)
        css = {'all': ('xstatic/themes/smoothness/jquery-ui.min.css', )}

    @classmethod
    def is_enabled(cls):
        return getattr(settings, 'FAMILY_SERVICE', None)

    def get_cell_extra_context(self, context):
        context = {}
        if getattr(self.context.get('request'), 'session', {}).get('mellon_session'):
            name_id = self.context['request'].session['mellon_session'].get('name_id_content')
            if name_id:
                params = {'NameID': name_id, 'orig': self.context['request'].get_host()}
                ws_family_url = sign_url(settings.FAMILY_SERVICE.get('url') +
                                         '/family/?' + urlencode(params),
                                         settings.FAMILY_SERVICE.get('signature_key'))
                context['family'] = requests.get(ws_family_url).json()
        return context

    def render(self, context):
        self.context = context
        if not context.get('synchronous'):
            raise NothingInCacheException()
        return super(FamilyInfosCell, self).render(context)
